@@ -3,10 +3,9 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef KMIME_HEADER_PARSING_P_H
-#define KMIME_HEADER_PARSING_P_H
+#pragma once
 
-#include <QVector>
+#include <QList>
 
 class QByteArray;
 
@@ -20,10 +19,9 @@ class Base;
 namespace HeaderParsing
 {
 
-Q_REQUIRED_RESULT QVector<KMime::Headers::Base *> parseHeaders(const QByteArray &head);
-
+[[nodiscard]] QList<KMime::Headers::Base *>
+parseHeaders(const QByteArray &head);
 }
 
 }
 
-#endif
